@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::metacpan_mod;
 
-our $DATE = '2018-09-07'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2019-06-24'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -70,7 +70,7 @@ App::lcpan::Cmd::metacpan_mod - Open module POD on MetaCPAN
 
 =head1 VERSION
 
-This document describes version 0.005 of App::lcpan::Cmd::metacpan_mod (from Perl distribution App-lcpan-CmdBundle-metacpan), released on 2018-09-07.
+This document describes version 0.006 of App::lcpan::Cmd::metacpan_mod (from Perl distribution App-lcpan-CmdBundle-metacpan), released on 2019-06-24.
 
 =head1 DESCRIPTION
 
@@ -83,7 +83,7 @@ This module handles the L<lcpan> subcommand C<metacpan-mod>.
 
 Usage:
 
- handle_cmd(%args) -> [status, msg, result, meta]
+ handle_cmd(%args) -> [status, msg, payload, meta]
 
 Open module POD on MetaCPAN.
 
@@ -113,6 +113,13 @@ using the C<index_name>.
 
 =item * B<modules>* => I<array[perl::modname]>
 
+=item * B<use_bootstrap> => I<bool> (default: 1)
+
+Whether to use bootstrap database from App-lcpan-Bootstrap.
+
+If you are indexing your private CPAN-like repository, you want to turn this
+off.
+
 =back
 
 Returns an enveloped result (an array).
@@ -120,7 +127,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -148,7 +155,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
